<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 获取参数
$member_id = isset($_GET['member_id']) ? intval($_GET['member_id']) : 0;
$search_term = isset($_GET['search']) ? trim($_GET['search']) : '';
$page = isset($_GET['p']) ? intval($_GET['p']) : 1;
$limit = 20; // 每页显示的记录数
$offset = ($page - 1) * $limit;
$transaction_type = isset($_GET['type']) ? trim($_GET['type']) : '';

// 构建查询条件
$where_conditions = [];
$params = [];
$param_types = '';

// 按会员ID筛选
if ($member_id > 0) {
    $where_conditions[] = 'pt.member_id = ?';
    $params[] = $member_id;
    $param_types .= 'i';
}

// 按交易类型筛选
if (!empty($transaction_type)) {
    $where_conditions[] = 'pt.transaction_type = ?';
    $params[] = $transaction_type;
    $param_types .= 's';
}

// 搜索条件
if (!empty($search_term)) {
    $where_conditions[] = '(pt.description LIKE ? OR m.member_no LIKE ? OR c.customer_name LIKE ?)';
    $search_param = '%' . $search_term . '%';
    $params[] = $search_param;
    $params[] = $search_param;
    $params[] = $search_param;
    $param_types .= 'sss';
}

// 组合WHERE子句
$where_clause = !empty($where_conditions) ? 'WHERE ' . implode(' AND ', $where_conditions) : '';

// 获取会员信息（如果提供了会员ID）
$member_info = null;
if ($member_id > 0) {
    $member_sql = "SELECT m.*, c.customer_name, c.phone 
                   FROM members m 
                   JOIN customers c ON m.customer_id = c.customer_id 
                   WHERE m.member_id = ?";
    $member_stmt = $conn->prepare($member_sql);
    $member_stmt->bind_param('i', $member_id);
    $member_stmt->execute();
    $member_result = $member_stmt->get_result();

    if ($member_result->num_rows > 0) {
        $member_info = $member_result->fetch_assoc();
    }

    $member_stmt->close();
}

// 获取交易记录总数
$count_sql = "SELECT COUNT(*) as total 
              FROM point_transactions pt 
              LEFT JOIN members m ON pt.member_id = m.member_id 
              LEFT JOIN customers c ON m.customer_id = c.customer_id 
              $where_clause";

$count_stmt = $conn->prepare($count_sql);
if (!empty($params)) {
    $count_stmt->bind_param($param_types, ...$params);
}
$count_stmt->execute();
$count_result = $count_stmt->get_result();
$count_row = $count_result->fetch_assoc();
$total_records = $count_row['total'];
$total_pages = ceil($total_records / $limit);
$count_stmt->close();

// 获取交易记录
$transactions_sql = "SELECT pt.*, m.member_no, c.customer_name 
                     FROM point_transactions pt 
                     LEFT JOIN members m ON pt.member_id = m.member_id 
                     LEFT JOIN customers c ON m.customer_id = c.customer_id 
                     $where_clause 
                     ORDER BY pt.transaction_date DESC, pt.transaction_id DESC 
                     LIMIT ?, ?";
$transactions = [];

$transactions_stmt = $conn->prepare($transactions_sql);
if (!empty($params)) {
    $all_params = $params;
    $all_params[] = $offset;
    $all_params[] = $limit;
    $transactions_stmt->bind_param($param_types . 'ii', ...$all_params);
} else {
    $transactions_stmt->bind_param('ii', $offset, $limit);
}

$transactions_stmt->execute();
$transactions_result = $transactions_stmt->get_result();

while ($row = $transactions_result->fetch_assoc()) {
    $transactions[] = $row;
}

$transactions_stmt->close();

// 获取交易类型列表
function getTransactionTypes()
{
    return [
        'purchase' => '消费积分',
        'redemption' => '积分兑换',
        'adjustment' => '积分调整',
        'expiration' => '积分过期',
        'signup' => '注册奖励',
        'promotion' => '促销活动'
    ];
}

// 获取交易类型名称
function getTransactionTypeName($type)
{
    $types = getTransactionTypes();
    return isset($types[$type]) ? $types[$type] : '未知类型';
}

// 获取交易类型样式类
function getTransactionTypeClass($type)
{
    switch ($type) {
        case 'purchase':
            return 'success';
        case 'redemption':
            return 'warning';
        case 'adjustment':
            return 'info';
        case 'expiration':
            return 'secondary';
        case 'signup':
            return 'primary';
        case 'promotion':
            return 'info';
        default:
            return '';
    }
}

// 生成分页URL
function buildPageUrl($page, $member_id, $search_term, $transaction_type)
{
    $params = [];

    if ($member_id > 0) {
        $params['member_id'] = $member_id;
    }

    if (!empty($search_term)) {
        $params['search'] = $search_term;
    }

    if (!empty($transaction_type)) {
        $params['type'] = $transaction_type;
    }

    $params['p'] = $page;

    return 'index.php?page=points&action=transactions&' . http_build_query($params);
}
?>

<div class="page-header">
    <h3>积分交易记录</h3>
    <div class="page-header-actions">
        <?php if ($member_id > 0): ?>
            <a href="index.php?page=points&action=redeem&member_id=<?php echo $member_id; ?>" class="btn btn-primary">积分兑换</a>
            <a href="index.php?page=points&action=transactions" class="btn">显示所有交易</a>
        <?php else: ?>
            <a href="index.php?page=points" class="btn btn-primary">返回积分商品</a>
        <?php endif; ?>
    </div>
</div>

<?php if ($member_info): ?>
    <div class="member-info-box">
        <h4>会员信息</h4>
        <div class="member-details">
            <div class="member-item">
                <label>会员卡号：</label>
                <span><?php echo htmlspecialchars($member_info['member_no']); ?></span>
            </div>
            <div class="member-item">
                <label>会员姓名：</label>
                <span><?php echo htmlspecialchars($member_info['customer_name']); ?></span>
            </div>
            <div class="member-item">
                <label>当前积分：</label>
                <span class="points"><?php echo number_format($member_info['points']); ?></span>
            </div>
            <div class="member-item">
                <label>联系电话：</label>
                <span><?php echo htmlspecialchars($member_info['phone']); ?></span>
            </div>
        </div>
        <div class="member-actions">
            <a href="index.php?page=points&action=redeem&member_id=<?php echo $member_id; ?>" class="btn btn-primary">积分兑换</a>
            <a href="index.php?page=member&action=view&id=<?php echo $member_id; ?>" class="btn">查看会员详情</a>
            <a href="index.php?page=points&action=transactions" class="btn">显示所有交易</a>
        </div>
    </div>
<?php endif; ?>

<div class="filter-box">
    <form method="get" class="filter-form">
        <input type="hidden" name="page" value="points">
        <input type="hidden" name="action" value="transactions">

        <?php if ($member_id > 0): ?>
            <input type="hidden" name="member_id" value="<?php echo $member_id; ?>">
        <?php endif; ?>

        <div class="form-group">
            <input type="text" name="search" class="form-control" value="<?php echo htmlspecialchars($search_term); ?>" placeholder="会员名称/卡号/描述">
        </div>

        <div class="form-group">
            <select name="type" class="form-control">
                <option value="">所有类型</option>
                <?php foreach (getTransactionTypes() as $type_key => $type_value): ?>
                    <option value="<?php echo $type_key; ?>" <?php echo ($transaction_type == $type_key) ? 'selected' : ''; ?>>
                        <?php echo $type_value; ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </div>

        <div class="form-group">
            <button type="submit" class="btn btn-primary">筛选</button>
            <a href="index.php?page=points&action=transactions<?php echo ($member_id > 0) ? '&member_id=' . $member_id : ''; ?>" class="btn btn-secondary">重置</a>
        </div>
    </form>
</div>

<div class="transactions-section">
    <?php if (empty($transactions)): ?>
        <div class="alert alert-info">未找到符合条件的交易记录</div>
    <?php else: ?>
        <table class="data-table">
            <thead>
                <tr>
                    <th width="60">#</th>
                    <?php if ($member_id == 0): ?>
                        <th>会员</th>
                    <?php endif; ?>
                    <th width="120">交易类型</th>
                    <th width="100">积分变动</th>
                    <th width="120">交易时间</th>
                    <th>说明</th>
                    <th width="80">相关ID</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($transactions as $transaction): ?>
                    <tr>
                        <td><?php echo $transaction['transaction_id']; ?></td>
                        <?php if ($member_id == 0): ?>
                            <td>
                                <a href="index.php?page=points&action=transactions&member_id=<?php echo $transaction['member_id']; ?>">
                                    <?php echo htmlspecialchars($transaction['customer_name']); ?>
                                    <small>(<?php echo htmlspecialchars($transaction['member_no']); ?>)</small>
                                </a>
                            </td>
                        <?php endif; ?>
                        <td>
                            <span class="badge badge-<?php echo getTransactionTypeClass($transaction['transaction_type']); ?>">
                                <?php echo getTransactionTypeName($transaction['transaction_type']); ?>
                            </span>
                        </td>
                        <td class="points-change <?php echo ($transaction['points'] >= 0) ? 'positive' : 'negative'; ?>">
                            <?php echo ($transaction['points'] >= 0 ? '+' : '') . number_format($transaction['points']); ?>
                        </td>
                        <td><?php echo date('Y-m-d', strtotime($transaction['transaction_date'])); ?></td>
                        <td><?php echo htmlspecialchars($transaction['description']); ?></td>
                        <td>
                            <?php if ($transaction['related_id']): ?>
                                <?php if ($transaction['transaction_type'] == 'redemption'): ?>
                                    <a href="#" title="兑换ID: <?php echo $transaction['related_id']; ?>">
                                        #<?php echo $transaction['related_id']; ?>
                                    </a>
                                <?php else: ?>
                                    #<?php echo $transaction['related_id']; ?>
                                <?php endif; ?>
                            <?php else: ?>
                                -
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- 分页 -->
        <?php if ($total_pages > 1): ?>
            <div class="pagination">
                <ul>
                    <?php if ($page > 1): ?>
                        <li><a href="<?php echo buildPageUrl(1, $member_id, $search_term, $transaction_type); ?>">首页</a></li>
                        <li><a href="<?php echo buildPageUrl($page - 1, $member_id, $search_term, $transaction_type); ?>">&laquo; 上一页</a></li>
                    <?php else: ?>
                        <li class="disabled"><span>首页</span></li>
                        <li class="disabled"><span>&laquo; 上一页</span></li>
                    <?php endif; ?>

                    <?php
                    // 显示当前页附近的页码
                    $start_page = max(1, $page - 2);
                    $end_page = min($total_pages, $page + 2);

                    for ($i = $start_page; $i <= $end_page; $i++): ?>
                        <li <?php echo ($i == $page) ? 'class="active"' : ''; ?>>
                            <?php if ($i == $page): ?>
                                <span><?php echo $i; ?></span>
                            <?php else: ?>
                                <a href="<?php echo buildPageUrl($i, $member_id, $search_term, $transaction_type); ?>"><?php echo $i; ?></a>
                            <?php endif; ?>
                        </li>
                    <?php endfor; ?>

                    <?php if ($page < $total_pages): ?>
                        <li><a href="<?php echo buildPageUrl($page + 1, $member_id, $search_term, $transaction_type); ?>">下一页 &raquo;</a></li>
                        <li><a href="<?php echo buildPageUrl($total_pages, $member_id, $search_term, $transaction_type); ?>">末页</a></li>
                    <?php else: ?>
                        <li class="disabled"><span>下一页 &raquo;</span></li>
                        <li class="disabled"><span>末页</span></li>
                    <?php endif; ?>
                </ul>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<style>
    .filter-section {
        background-color: #f8f9fa;
        padding: 15px;
        border-radius: 5px;
        margin-bottom: 20px;
    }

    .member-info-box {
        background-color: #f9f9f9;
        border: 1px solid #ddd;
        border-radius: 4px;
        padding: 15px;
        margin-bottom: 20px;
    }

    .member-details {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        margin-bottom: 15px;
    }

    .member-item {
        flex: 1 0 45%;
        min-width: 200px;
    }

    .member-item label {
        font-weight: bold;
        display: inline-block;
        min-width: 100px;
    }

    .member-actions {
        display: flex;
        gap: 10px;
        margin-top: 10px;
        border-top: 1px solid #eee;
        padding-top: 15px;
    }

    .points {
        font-weight: bold;
        color: #d9534f;
    }

    .points-change {
        font-weight: bold;
    }

    .points-change.positive {
        color: #28a745;
    }

    .points-change.negative {
        color: #dc3545;
    }

    .badge {
        display: inline-block;
        padding: 3px 8px;
        font-size: 12px;
        font-weight: 600;
        border-radius: 3px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-info {
        background-color: #17a2b8;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    .badge-primary {
        background-color: #007bff;
    }

    /* 统一表格样式 */
    .data-table-wrapper {
        overflow-x: auto;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
        margin-bottom: 20px;
    }

    .data-table th,
    .data-table td {
        padding: 12px 10px;
        text-align: left;
        vertical-align: middle;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .data-table tr:hover {
        background-color: #f2f2f2;
    }

    .data-table small {
        display: block;
        color: #6c757d;
        font-size: 12px;
    }

    .page-header {
        margin-bottom: 20px;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .page-header-actions {
        display: flex;
        gap: 10px;
    }

    @media (max-width: 767px) {
        .member-item {
            flex: 1 0 100%;
        }

        .member-actions {
            flex-direction: column;
            gap: 5px;
        }
    }

    .filter-box {
        background-color: #f8f9fa;
        padding: 15px;
        border-radius: 5px;
        margin-bottom: 20px;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: flex-end;
    }

    .filter-form .form-group {
        margin-bottom: 0;
        min-width: 150px;
    }
</style>